package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````&",```````!``````````)BA````
M`````````$``.``(`$``&0`8``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````"24````````))0`````````
M``$```````$````&`````)L`````````FP$```````";`0``````@`4`````
M``"H%0```````````0```````@````8````0FP```````!";`0``````$)L!
M``````!0`@```````%`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0`````FP````````";`0```````)L!````````!0``````
M```%`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`1[=C,7R61T332LT-IM=I%VP/T:D1````3P````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A/````4````%0```!9````6@``
M`&$```!B````8P```&4```!F`````````&@```!I````:@```&P`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`)`<````````````````````````
M`P`5``"@`0`````````````````5`P``$@`````````````````````````N
M`P``$@````````````````````````"U`@``$@``````````````````````
M``#B`@``$@`````````````````````````V`P``$@``````````````````
M``````")`@``$@`````````````````````````1````(```````````````
M``````````##`@``$@````````````````````````"``@``$@``````````
M``````````````#I`@``(@````````````````````````"N`@``$@``````
M``````````````````"7`@``$@````````````````````````"T````$@``
M``````````````````````!$`P``$0````````````````````````"#`0``
M$@````````````````````````#X`@``$@````````````````````````"$
M````$@`````````````````````````,`0``$@``````````````````````
M``!B`@``$@````````````````````````!4`@``$@``````````````````
M``````"J`0``$@`````````````````````````!`0``$0``````````````
M```````````_`@``$@````````````````````````!G`0``$@``````````
M``````````````#C````$0`````````````````````````U`0``$@``````
M``````````````````!B`P``$@`````````````````````````<`P``$@``
M``````````````````````"G`@``$@````````````````````````#"````
M$@````````````````````````"Q`0``$@`````````````````````````B
M`@``$@````````````````````````">`0``$@``````````````````````
M``#P`0``$@````````````````````````"?`@``$@``````````````````
M``````#;`@``$@````````````````````````".`@``$@``````````````
M``````````!1`P``$@`````````````````````````$`@``$@``````````
M``````````````!#`0``$@`````````````````````````M````(```````
M``````````````````">`P``$0````````````````````````!+`P``$@``
M``````````````````````#4`@``$@````````````````````````"\`0``
M$0````````````````````````!D````$@````````````````````````!P
M`P``$@````````````````````````!O`@``$@``````````````````````
M```K!```$@`````````````````````````Y`@``$@``````````````````
M``````"3````$@````````````````````````"?````$@``````````````
M``````````!<`0``$@`````````````````````````*`P``$@``````````
M```````````````B`0``$@`````````````````````````1`0``$@``````
M``````````````````!6````$@````````````````````````!V`@``$@``
M```````````````````````6`0``$@````````````````````````"3`0``
M$@````````````````````````#P````$@````````````````````````!-
M`@``$@````````````````````````!U`0``$@``````````````````````
M``!S````$@`````````````````````````J`@``$@``````````````````
M``````"\`@``$@````````````````````````!^`P``$0``````````````
M``````````"``P``$0`````````````````````````*`@``$@``````````
M``````````````#4````$@````````````````````````!3`0``$@``````
M``````````````````#-`@``$@`````````````````````````\````(```
M```````````````````````1`@``$@````````````````````````!;`@``
M$@````````````````````````!J`P``$@````````````````````````#@
M`P``$``6`*BP`0`````````````````T!```$@`-`*A2````````@```````
M```"!```$@`.`+Q3``````````````````!9!```$@`-`-!$````````F`D`
M```````I`P``$@`-`-`@````````2`(````````(!```$@`-`+@]````````
M!`````````#1`P``$``6`("@`0````````````````#'!```$@`-`,`]````
M````0`(```````#!!```$@`+`)`<``````````````````#T!```$@`-`&A.
M````````0`0```````#%`P``$``6`("@`0````````````````!`!```$@`-
M``!`````````*`````````!S!```$0`/`-!3````````!`````````#S`P``
M$``6`*BP`0````````````````#K`P``$``6`*BP`0````````````````"_
M!```$@`-`$@\````````.`````````#4!```$@`-`,A#````````!`$`````
M``#F!```$@`-`!A#````````B`````````!F!```$``5``"@`0``````````
M``````!-!```$@`-`"A`````````*`$```````"^`P``$``5`("@`0``````
M``````````"H!```$0`5`'B@`0``````"`````````#X`P``$@`-`+A3````
M````!`````````"8!```$@`-`#A3````````@`````````!L!```$@`-`!@C
M``````````````````!H!```(``5``"@`0`````````````````9!```$@`-
M`*!#````````*`````````#?`P``$``6`*BP`0````````````````""!```
M$@`-`-@\````````W`````````"R!```$@`-`%!!````````Q`$`````````
M;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``
M<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A
M=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`')M9&ER`%]?<W1R;F-P>5]C
M:&L`<W1R8VAR`&=E='!I9`!U;FQI;FL`7U]M96UC<'E?8VAK`'-T<F-M<`!R
M96%D9&ER-C0`<F5A9&QI;FL`97AI=`!C;&]S961I<@!O<&5N9&ER`')E86QL
M;V,`;65M<V5T`&=E='5I9`!S=')T;VL`;65M8VAR`%]?>'-T870V-`!S=')S
M='(`86-C97-S`'-T<F1U<`!S=')L96X`7U]C>&%?9FEN86QI>F4`7U]R96=I
M<W1E<E]A=&9O<FL`7U]L>'-T870V-`!M96UC<'D`7U]L:6)C7W-T87)T7VUA
M:6X`;65M;6]V90!?7W-P<FEN=&9?8VAK`'-T9&5R<@!A8F]R=`!?7W-T86-K
M7V-H:U]F86EL`'-T<FYC;7``;6MD:7(`7U]F<')I;G1F7V-H:P!?7V5N=FER
M;VX`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?<W1A8VM?8VAK7V=U87)D`&QI
M8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`
M7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?
M8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C
M;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`
M7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X
M<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV
M7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C$W````````
M```"``(``@`"``(``@````(``@`"``(``@````(````"```````"``(``@``
M``(``````````@`"``(```````,````#``(``@`"``(``P``````!``"``(`
M``````(``@`"``(``````````@````(````"``````````(```````,``@`"
M``(``P```````@````,``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0"(`P``$```
M`"````"7D98&```$``H%`````````0`!`.`!```0````(````)>1E@8```,`
M"@4````````!``$`+P(``!``````````EY&6!@```@`*!0````````";`0``
M`````P0````````@)`````````B;`0```````P0```````#8(P```````("?
M`0```````P0```````"X4P```````-"?`0```````P0````````X4P``````
M`."?`0```````P0```````#0(`````````B@`0```````P0````````(H`$`
M`````!B@`0```````P0```````#@5P```````""@`0```````P0````````0
M5````````#"@`0```````P0```````!P50```````#B@`0```````P0`````
M``#`5P```````$"@`0```````P0```````#(5P```````$B@`0```````P0`
M``````#05P```````%"@`0```````P0```````#85P```````&"@`0``````
M`P0```````"H5P```````&B@`0```````P0```````"P5P```````'B@`0``
M`````P0```````#H5P```````(B?`0```````00```D``````````````)"?
M`0```````00```P``````````````)B?`0```````00``!``````````````
M`*"?`0```````00``!$``````````````*B?`0```````00``!@`````````
M`````+"?`0```````00``!L``````````````+B?`0```````00``"L`````
M`````````,"?`0```````00``"P``````````````,B?`0```````00``"\`
M`````````````-B?`0```````00``#D``````````````.B?`0```````00`
M`$(``````````````/"?`0```````00``$8``````````````/B?`0``````
M`00``$L``````````````'B=`0```````@0```,``````````````("=`0``
M`````@0```0``````````````(B=`0```````@0```4``````````````)"=
M`0```````@0```8``````````````)B=`0```````@0```<`````````````
M`*"=`0```````@0```@``````````````*B=`0```````@0```H`````````
M`````+"=`0```````@0```L``````````````+B=`0```````@0```P`````
M`````````,"=`0```````@0```T``````````````,B=`0```````@0```X`
M`````````````-"=`0```````@0```\``````````````-B=`0```````@0`
M`!(``````````````."=`0```````@0``!,``````````````.B=`0``````
M`@0``!0``````````````/"=`0```````@0``!4``````````````/B=`0``
M`````@0``!8```````````````">`0```````@0``!<```````````````B>
M`0```````@0``!D``````````````!">`0```````@0``!H`````````````
M`!B>`0```````@0``!P``````````````"">`0```````@0``!T`````````
M`````"B>`0```````@0``!X``````````````#">`0```````@0``!\`````
M`````````#B>`0```````@0``"```````````````$">`0```````@0``"$`
M`````````````$B>`0```````@0``"(``````````````%">`0```````@0`
M`",``````````````%B>`0```````@0``"0``````````````&">`0``````
M`@0``"4``````````````&B>`0```````@0``"8``````````````'">`0``
M`````@0``"<``````````````'B>`0```````@0``"@``````````````(">
M`0```````@0``"D``````````````(B>`0```````@0``"H`````````````
M`)">`0```````@0``"L``````````````)B>`0```````@0``"T`````````
M`````*">`0```````@0``"X``````````````*B>`0```````@0``#``````
M`````````+">`0```````@0``#$``````````````+B>`0```````@0``#(`
M`````````````,">`0```````@0``#,``````````````,B>`0```````@0`
M`#0``````````````-">`0```````@0``#4``````````````-B>`0``````
M`@0``#8``````````````.">`0```````@0``#<``````````````.B>`0``
M`````@0``#@``````````````/">`0```````@0``#H``````````````/B>
M`0```````@0``#L```````````````"?`0```````@0``#P`````````````
M``B?`0```````@0``#T``````````````!"?`0```````@0``#X`````````
M`````!B?`0```````@0``#\``````````````""?`0```````@0``$``````
M`````````"B?`0```````@0``$$``````````````#"?`0```````@0``$,`
M`````````````#B?`0```````@0``$0``````````````$"?`0```````@0`
M`$<``````````````$B?`0```````@0``$@``````````````%"?`0``````
M`@0``$D``````````````%B?`0```````@0``$H``````````````&"?`0``
M`````@0``$P``````````````&B?`0```````@0``$T``````````````'"?
M`0```````@0``$X``````````````/U[OZG]`P"1K@$`E/U[P:C``U_6````
M````````````\'N_J=```)`1ND;Y$,(UD2`"']8?(`/5'R`#U1\@`]70``"0
M$;Y&^1#B-9$@`A_6T```D!'"1OD0`C:1(`(?UM```)`1QD;Y$"(VD2`"'];0
M``"0$<I&^1!"-I$@`A_6T```D!'.1OD08C:1(`(?UM```)`1TD;Y$((VD2`"
M'];0``"0$=9&^1"B-I$@`A_6T```D!':1OD0PC:1(`(?UM```)`1WD;Y$.(V
MD2`"'];0``"0$>)&^1`"-Y$@`A_6T```D!'F1OD0(C>1(`(?UM```)`1ZD;Y
M$$(WD2`"'];0``"0$>Y&^1!B-Y$@`A_6T```D!'R1OD0@C>1(`(?UM```)`1
M]D;Y$*(WD2`"'];0``"0$?I&^1#"-Y$@`A_6T```D!'^1OD0XC>1(`(?UM``
M`)`1`D?Y$`(XD2`"'];0``"0$09'^1`B.)$@`A_6T```D!$*1_D00CB1(`(?
MUM```)`1#D?Y$&(XD2`"'];0``"0$1)'^1"".)$@`A_6T```D!$61_D0HCB1
M(`(?UM```)`1&D?Y$,(XD2`"'];0``"0$1Y'^1#B.)$@`A_6T```D!$B1_D0
M`CF1(`(?UM```)`1)D?Y$"(YD2`"'];0``"0$2I'^1!".9$@`A_6T```D!$N
M1_D08CF1(`(?UM```)`1,D?Y$((YD2`"'];0``"0$39'^1"B.9$@`A_6T```
MD!$Z1_D0PCF1(`(?UM```)`1/D?Y$.(YD2`"'];0``"0$4)'^1`".I$@`A_6
MT```D!%&1_D0(CJ1(`(?UM```)`12D?Y$$(ZD2`"'];0``"0$4Y'^1!B.I$@
M`A_6T```D!%21_D0@CJ1(`(?UM```)`15D?Y$*(ZD2`"'];0``"0$5I'^1#"
M.I$@`A_6T```D!%>1_D0XCJ1(`(?UM```)`18D?Y$`([D2`"'];0``"0$69'
M^1`B.Y$@`A_6T```D!%J1_D00CN1(`(?UM```)`1;D?Y$&([D2`"'];0``"0
M$7)'^1"".Y$@`A_6T```D!%V1_D0HCN1(`(?UM```)`1>D?Y$,([D2`"'];0
M``"0$7Y'^1#B.Y$@`A_6T```D!&"1_D0`CR1(`(?UM```)`1AD?Y$"(\D2`"
M']:P``#P$8I'^1!"/)$@`A_6L```\!&.1_D08CR1(`(?UK```/`1DD?Y$((\
MD2`"']:P``#P$99'^1"B/)$@`A_6L```\!&:1_D0PCR1(`(?UK```/`1GD?Y
M$.(\D2`"']:P``#P$:)'^1`"/9$@`A_6L```\!&F1_D0(CV1(`(?UK```/`1
MJD?Y$$(]D2`"']:P``#P$:Y'^1!B/9$@`A_6L```\!&R1_D0@CV1(`(?UK``
M`/`1MD?Y$*(]D2`"']:P``#P$;I'^1#"/9$@`A_6_7NYJ?T#`)'S4P&ILP``
M\+0``/!CXD?YHH<$J:(C`9%D`$#YI#<`^00`@-*@7P"YH4,!D:!S`9&*__^7
MH```\*(``/``]$?Y0NQ'^>$#`JJ"#`"4H```\`#81_D``$`Y8`$`-4O__Y?"
M``"00%``^4`.`+2T``#P%O__EX#61_D``$"Y3___EQ^$)#F4UD?Y@`)`N4O_
M_Y<!Z%,Y(0`?,@'H$SF``D"Y1O__EP+H4SFA7T"Y`P#\DD(``#("Z!,Y(10`
M$;5;`JFW&P#Y(7Q`DS\``^MH"@!4(/!]TS7__Y>E*T#YP@``D-0``)"$(@*1
M1SQ`^0,``/`!``#P8V`>D:@`0/DA@!Z1A@"`4J)?0+D(#`"I!P0!J5\$`'&&
M!`"Y@`0`^4T!`%0A`(#2Y@"`DB00`!&C>&'XQ,PDBR$$`)%?``%K`V@D^$S_
M_U26(@*111``$07,)8OC`P"J`0``L`0`@-+`#D#Y0@P`$;^`'_@A`#*1;___
ME_4#`"J@`P`TEB("D;>3`9'`#D#YZ?[_EP```/#A`Q>J```4D:<$`)0``@"T
ME"("D8`.0/G-_O^75/__EW/B1_G@`Q4JHC=`^6$"0/E!``'*80,`M;5;0JGS
M4T&IMQM`^?U[QZC``U_6P`I`^>```+3\"P"4[O__%\`.0/EO__^7]0,`*N'_
M_Q<```#PX0,7J@`@$I&+!`"4P`H`^8#\_[3P"P"4XO__%Z$``/````#P`$`>
MD2'D1_DD__^7\_[_E[5;`JD@`(!2MQL`^8/^_Y<=`(#2'@"`TN4#`*KA`T#Y
MXB,`D>8#`)&@``#P`/!'^:,``/!CZ$?YI```\(3`1_FZ_O^7\?[_EZ```/``
MW$?Y0```M.G^_Q?``U_6`````,```)````*1P0``D"$``I$_``#KH```5*$`
M`/`AQ$?Y00``M"``'];``U_6'R`#U<```)````*1P0``D"$``I$A``#+(?Q#
MDR'\08LA_$&3P0``M*(``/!"_$?Y8@``M$``']8?(`/5P`-?UA\@`]7]>[ZI
M_0,`D?,+`/G3``"08`)".4`!`#6@``#P`,A'^8```+3```"0``1`^5/^_Y?8
M__^7(`"`4F`"`CGS"T#Y_7O"J,`#7];>__\7`````/^#"M&H``#P!.``D0G@
M`9']>P"I_0,`D:)C`)$!X4?Y1R``D2,`0/FC3P'Y`P"`TH$`0+F#A$#X(0C`
M6N&`'_B?``GK8?Q@TV7\:-,FW'C3I1QXDB$<"%/&''"2(0`&JJ/@0ZHA``.J
MX00!^"'^_U1&``B11`!`^4(@`)%#!$#Y11Q`^4$P0/EC``3*7P`&ZR$`!<HA
M``/*(_Q?TV$$`:HA?$"203P`^6'^_U0%$$"I@`!GG@8<0:GA`&>>P@!GGH'\
M0M,A>`2JH_Q;TT`<82XL?$"2@0%GGF,4!:JKOT&I*C./TDI0J_()$$#Y#0!F
MGJ``9YYK`0J+HOQ"TR`<8BY">`6J[P$*BR$``LJC02.+L!=`^6,`"XM-?$"2
M8P`)"Q`""HL.`&:>:_Q;TVL5`ZHA``.*(0`,RK%C0/DA``:+S@$'BR$`$(O.
M`0^+;_Q"TVL!#@OC>0.J;OU;TT(``\I"``N*SA4+JLX!`0M!``W*KPM#J7#]
M0M,0>@NJ(0`,B^\!"HML`!#*(0`/BV-\0)++_5O3C`$.BL_]0M-K%0ZJ[WD.
MJHP!`\IK`0$+3@`*BXP!#8L-`@_*`7Y`DHP!#HMB_5O3K0$+BF[]0M-"%`NJ
MK0$!RLMY"ZI"``P+K0$#B^P!"\KC?4"2L#]$J4[\6]/.%0*JC`$"BA`""HN,
M`0/*K0$0B^\!"HO.`0T+@0$!BU#\0M/-_5O3`GH"JB$`#XNM%0ZJS_U"TZT!
M`0ML`0+*X7D.JFM]0)*P/T6IC`$.BHP!"\JN_5O3$`(*BX,!`XM,``'*8P`0
MBT)\0)+.%0VJC`$-BLX!`PN,`0+*L/U"TP-Z#:KO`0J+BP$+B\W]6]-K`0^+
MK14.JL_]0M.M`0L++``#RNMY#JJP/T:I(7Q`DHP!#HJN_5O3C`$!RA`""HN"
M`0*+;``+RD(`$(MC?$"2SA4-JHP!#8K.`0(+C`$#RK#]0M/O`0J+@0$!B\S]
M6],">@VJ(0`/BXP5#JK/_4+3C`$!"VT!`LKA>0ZJ:WU`DK`_1ZFM`0Z*K0$+
MRH[]6],0`@J+HP$#BTT``<IC`!"+0GQ`DLX5#*JM`0R*D/U"T\X!`PL,>@RJ
MK0$"RN\!"HLC``S*JP$+B\W]6],A?$"2:P$/B[!#0/FM%0ZJ8P`.BL_]0M.M
M`0L+[WD.JF,``<H.`@J+BP$/RF,``HNB_5O3C'U`DF,`#HNP1T#Y0A0-JFL!
M#8JN_4+30@`#"\YY#:IK`0S*#0(*B^,!#LIK`0&+0?Q;T^]]0))K`0V+L$M`
M^2$4`JIC``**3?Q"TR$`"PNM>0*J8P`/RLL!#<IC``R+(OQ;TPP""HO.?4"2
M8P`,BT(4`:IK`0&*L$]`^4(``PMK`0[*+/Q"TXQY`:H0`@J+:P$/BT'\6]-K
M`1"+(10"JE#\0M,A``L+HP$,R@MZ`JIC``**@@$+RJ]30/FM?4"2C'U`DD(`
M`8IC``W*0@`,RF,`#HM"``V+[@$*BR_\6].PMTJI8P`.B^\5`:HN_$+3[P$#
M"\YY`:KC_5O3`0(*BV,4#ZI"``&+80$.RD)`(XMK?4"2(0`/BD-\0)(A``O*
MJ@$*BR$`#(OM_4+3;/Q;TR$`"HN,%0.JJGD/JBQ`+(NM7T#YP0$*RI!]0)(A
M``)*(G2=TBL`"XLBVZWR;_Q"TZ$!`HL-_EO3XWD#JF$!`8NM%1"J2P$#RBU`
M+8MK`0Q*KWU`DFM!+HOL_5O3+@("BP'^0M-K`0Z+(7@0JHP5#ZIL02R+L&=`
M^6L``<J.?4"2;0$-2A`"`HNJ02J+Z_U"T\W]6]-K>0^J2@$0BZT5#JI-02V+
ML&M`^2H`"\JO?4"22@$,2A`"`HM*02.+[/U;T\/]0M-*`1"+8W@.JHP5#ZI,
M02R+L&]`^6H!`\J.?4"22@$-2A`"`HM!02&+S?U;T^K]0M,A`!"+2GD/JJT5
M#JHM0"V+L'-`^6$`"LJO?4"2+``,2A`"`HN+02N+P?U"T^S]6],A>`ZJ:P$0
MBXP5#ZIL02R+L'=`^4L!`<J.?4"2;0$-2A`"`HNC02.+Z_U"T\W]6]-K>0^J
M8P`0BZT5#JJP>T#Y;4`MBR,`"\JO?4"2;``,2A`"`HN*02J+P_U"T^S]6]-C
M>`ZJ2@$0BXP5#ZI,02R+L']`^6H!`\J.?4"230$-2A`"`HNA02&+ZOU"T\W]
M6]-*>0^J(0`0BZT5#JHM0"V+L(-`^6$`"LJO?4"2+``,2A`"`HN+02N+P?U"
MT^S]6],A>`ZJ:P$0BXP5#ZIL02R+L(=`^4L!`<J.?4"2;0$-2A`"`HNC02.+
MZ_U"T\W]6]-K>0^J8P`0BZT5#JIM0"V+L(M`^2,`"\JO?4"2;``,2A`"`HN*
M02J+P_U"T^S]6]-C>`ZJ2@$0BXP5#ZI,02R+L(]`^6H!`\J.?4"230$-2A`"
M`HNA02&+ZOU"T\W]6]-*>0^J(0`0BZT5#JHM0"V+80`*RBP`#$K!_4+3(7@.
MJJ]]0)*P.U*IBT$KB^S]6],0`@*+C!4/JFL!$(MK02R+3`$!RG!]0)*-`0U*
MHT$CB^S]0M/-`0*+#OY;TXQY#ZIC``V+SA40JFY`+HLC``S*:P`+2@/^0M-C
M>!"JSWU`DJU#4ZEJ02J+JP$"B^W]6]-*`0N+K14/JDU!+8N*`0/*3@$.2NK]
M0M-*>0^J$`("B\%!(8NK?4"2(0`0BW``"LH-`@U*;OU;TW#]0M/.%0NJ"WH+
MJBY`+HNO0U2IP7U`DJQ!+(LM_%O3[P$"BZT5`:J,`0^+3P$+RHQ!+8ON`0Y*
MC7U`DA`"`HO#02.+KOU;T\X5#:JQ_4+3+_Q"TV,`$(O#`0,+X7D!JBYZ#:IP
M`0'*KT=5J1`"#$K-?4"2+'Q`D@I"*HLA``ZJX@$"BV_\6],A``.*</Q"TT(!
M`HOJ%0.JCP$-BD(!`@L#>@.J(0`/JHJ;E])O?$"2:N.Q\BM`*XLQ`@J+P0$#
MJFL!$8LA``**L0$/BE#\6],A`!&J$!8"JJY'5JE2_$+3"P(+"T)Z`JI0?$"2
MS@$*BR$`#(MC``*J;/U;TW+]0M,A``Z+C!4+JNX!$(IC``N*C`$!"V,`#JI!
M>@NJ8P`-BRY\0)(M`@J+B_U;TT(``:IC``V+DOU"TPT"#HJQNT#Y:Q4,JD(`
M#(IK`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JG+]0M-"``^+L;]`
M^<\!#8J,%0NJ(0`+BHP!`@LA``^J0GH+JB$`$(M/?$"2,`(*BXO]6]-C``*J
MDOU"TR$`$(NQPT#YL`$/BFL5#*IC``R*:P$!"V,`$*I!>@RJ8P`.BS!\0)(N
M`@J+;/U;TT(``:IR_4+38P`.B[''0/GN`1"*C!4+JD(`"XJ,`0,+0@`.JD-Z
M"ZI"``V+;GQ`DBT""HN+_5O3(0`#JI+]0M-"``V+L<M`^0T"#HIK%0RJ(0`,
MBFL!`@LA``VJ0GH,JB$`#XM-?$"2+P(*BVS]6]-C``*J<OU"TR$`#XNQST#Y
MSP$-BHP5"ZIC``N*C`$!"V,`#ZI!>@NJ8P`0BR]\0)(P`@J+B_U;TT(``:J2
M_4+38P`0B['30/FP`0^*:Q4,JD(`#(IK`0,+0@`0JD-Z#*I"``Z+<'Q`DBX"
M"HML_5O3(0`#JG+]0M-"``Z+L==`^>X!$(J,%0NJ(0`+BHP!`@LA``ZJ0GH+
MJB$`#8M.?$"2+0(*BXO]6]-C``*JDOU"TR$`#8NQVT#Y#0(.BFL5#*IC``R*
M:P$!"V,`#:I!>@RJ8P`/BRU\0)(O`@J+;/U;TT(``:IR_4+38P`/B['?0/G/
M`0V*C!4+JD(`"XJ,`0,+0@`/JD-Z"ZI"`!"+;WQ`DC`""HN+_5O3(0`#JI+]
M0M-"`!"+L>-`^;`!#XIK%0RJ(0`,BFL!`@LA`!"J0GH,JB$`#HM0?$"2+@(*
MBVS]6]-C``*J<OU"TR$`#HNQYT#Y[@$0BHP5"ZIC``N*C`$!"V,`#JI!>@NJ
M8P`-BRY\0)(M`@J+B_U;TT(``:J2_4+38P`-B['K0/D-`@Z*:Q4,JD(`#(IK
M`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JD(`#XNQ[T#YSP$-BHP5
M"ZHA``N*C`$""W+]0M,A``^J0GH+JB$`$(N+_5O3,`(*BR$`$(MK%0RJ:P$!
M"T]\0)*Q!UZI8P`"JK`!#XIC``R*DOU"TV,`$*I,>@RJ,0(*BY!]0))"``RJ
M8P`.BV[]6]/.%0NJ0@`+BF,`$8OQ`1"*PP$#"T(`$:IN_4+3(0`*B\MY"ZI"
M``V+;?Q;TVY]0))"``&+K14#JH$!"ZI20"V+K/M`^0("#HHA``.*37Y`DB$`
M`JIB_$+30W@#JHH!"HLA``^+K/U;TV(!`\HA``J+C!4-JJ_]0M,L0"R+00`2
M2B$`$(N1?4"2JL-?J<(ZF-)"3+GR*_Y;TTH!`HMK%1&J(0`*B^IY#:HK0"N+
M80`*RF]]0)(A``Q*[?U;TPP"`HLA``Z++OY"T\YY$:HA``R+K14/JDP!#LHM
M0"V+H0=!^;!]0)*+`0M*(0`"BPS^6]-K02.+X_U"TVL!`8N,%1"J87@/JFQ!
M+(NC"T'YRP$!RH]]0))K`0U*8P`"B^W]6]-J02J+"_Y"TVMY$*I*`0.+K14/
MJB,`"\I-02V+J@]!^;!]0))C``Q*2@$"BPS^6]-C0"Z+[OU"TV,`"HN,%1"J
MRGD/JFQ`+(MN`0K*HQ-!^8]]0)+.`0U*8P`"B^W]6]/!02&+#OY"TR$``XNM
M%0^JPWD0JBU`+8M0`0/*H1=!^:Y]0)(0`@Q*(0`"B\S]6],+0BN+\/U"TVL!
M`8N,%0ZJ`7H/JFQ!+(MP``'*JQM!^8]]0)(0`@U*:P$"B^W]6],*0BJ+T/U"
MTTH!"XNM%0^J"WH.JDU!+8LP``O*JA]!^:Y]0)(0`@Q*2@$"B\S]6],#0B.+
M\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HR-!^8]]0)(0`@U*8P`"B^W]6],!
M0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H2=!^:Y]0)(0`@Q*(0`"B\S]
M6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JRM!^8]]0)(0`@U*:P$"
MB^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*JB]!^:Y]0)(0`@Q*
M2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HS-!^8]]0)(0
M`@U*8P`"B^W]6],!0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H3=!^:Y]
M0)(0`@Q*(0`"B\S]6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JSM!
M^8]]0)(0`@U*:P$"B^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*
MJC]!^:Y]0)(0`@Q*2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(NO
M0T'Y8P$*RI!]0))M``U*H4$ABP/^6]/M`0*+S_U"TV,4$*HA``V+[7D.JB%`
M(XNO1T'Y0P$-RBY\0))C``Q*#/Y"T^\!`HN,>1"J:T`KB\/]6]-K`0^+8Q0.
MJK`!#,JO2T'Y8P`+"P$"`4K+_4+3*D`JB^$!`HMB_%O32@$!BT(4`ZIA>0ZJ
M0@`*"R8`!@L(X4?YAP$'"ZD!"0M%``4+@P`#"P8<`:D%#`"I"1``^:%/0?D`
M`4#Y(```RH```+7]>T"I_X,*D<`#7]9T^O^7'R`#U?U[O*G]`P"1\PL`^8`'
M`+2B``#0N!\`^4+X1_E8`$#Y.`<`M+43`/D5`(!2`@!`.5_T`'%$&$!Z00,`
M5!,#0/F3!0"TMM\"J;5^0).T#P#Y]P,!JO8#`*KT`QBJX`,3JN(#%:KA`Q:J
M+/K_EX```#5@:G4X'_0`<4`"`%23CD#X\_[_M;370:FVWT*IN!]`^>`#$ZKS
M"T#Y_7O$J,`#7];U`P"JHAY`.%_T`'%$&$!ZH?__5+4"`$OA__\7'R`#U90"
M&,NU!@"1E/Y#D_0"`+ES`A6+X`,3JK@?0/FTUT&IMM]"J?,+0/G]>\2HP`-?
MUK430/FX'T#YYO__%Q,`@-+D__\7$P"`TK@?0/GA__\7_7N\J?T#`)'U6P*I
MM@``T/-3`:FS``#0]0,`JL#B1_ES^D?YM-,`D0$`0/FA'P#Y`0"`TN$#%*K@
M`Q6JK?__E^`!`+2C-X"Y8@)`^4`,`XL!!$#Y07@C^.'^_[0`(`"1`01`^0$`
M`/FA__^UX0,4JN`#%:J?__^78/[_M=;B1_FA'T#YP`)`^2```,J@``"U\U-!
MJ?5;0JG]>\2HP`-?U@;Z_Y<?(`/5_7NYJ?T#`)'S4P&I\P,!JO5;`JFU``#0
M]V,#J?0#`*JAXD?Y8`)`.2(`0/FB-P#Y`@"`TA_T`'%S%I.:X`,3JH#Y_Y?V
M`P"JH9,!D>`#%*I^__^7X`<`M/<#`*IY^?^7'P`6ZZ(&`%2X9X"YMP``T!CS
M?=.``D`Y'_0`<0080'J`#`!4X0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+(7Q`
MD_?Z1_G`"@"1```!B_8"0/F<^?^7P&HX^*`+`+2C9X"Y@`8`D>("0/F!`D`Y
M/_0`<4)X8_@D&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5$$$`)&@
M!X!20```.6`60#@@%``XP/__-0``@%*UXD?YHC=`^:$"0/E!``'*H0@`M?-3
M0:GU6T*I]V-#J?U[QZC``U_6``"`TF%J8#CA:B`X``0`D:'__S7P__\7MP``
MT+EK!*F[*P#YX/I'^1@`0/D``T#Y@`4`M.$#&*H``(!2`@``%.`#&2HBC$#X
M&00`$:+__[4`#``1`'Q]DZ$``/`BB$"Y@@(`-2(`@%(BB`"Y7_G_E_L#`*K`
M`P"T.G]`D^$#&*I8\WW3X@,8JACY_Y?@^D?Y&P``^5H'`)%_>SKXN6<`N;LK
M0/FY:T2II?__%Q\@`]7A`P"JX`,8JGSY_Y?[`P"JX/I'^1L``/D[`0"T.G]`
MDUCS?=/P__\7`0"`TJ/__Q<``H#2&0"`4MS__Q>Y:T2INRM`^0``@!*X__\7
MN6L$J;LK`/EU^?^7_7NRJ?T#`)'S"P#YLP``T&'B1_DB`$#YHF\`^0(`@-+`
M``"TM`\`^?0#`*H!`$`Y00$`-;0/0/ESXD?YH6]`^6`"0/D@``#*P`D`M?,+
M0/G]>\ZHP`-?UK87`/D%^?^7]@,`JN`&`+2W8P.I%P``T!@``-"Z)P#Y]T(0
MD1AC$)&Z8P&1M1,`^>`#%JJ5^?^7``8`M!5,`)'A`Q>JX`,5JFSY_Y<@__\T
MX0,8JN`#%:IH^?^7H/[_-+DC`/G@`Q2JT/C_E_D#`*K@`Q6JS?C_EP``&0L`
M"``1`'Q`DP'Y_Y?E`Q6JY`,4J@,``-!C@!"1^0,`J@(`@)(A`(!2Q?C_E^(#
M&JKA`QFJ``"`4LGX_Y<?!``QH```5*!K0+D`#!02'Q!`<8`"`%3@`QFJH?G_
ME^`#&:IC^?^7N2-`^=/__Q>T#T#YMA=`^;S__Q<?(`/5X`,6JAOY_Y?@`Q2J
M1?G_E[370:FVWT*IN!]`^;HG0/FR__\7X`,9JJ+__Y?M__\7M-<!J;;?`JFX
MYP.INB<`^1#Y_Y<?(`/5_7N^J?T#`)'S4P&ILP``T/0#`*ISUD?Y8`)`N??X
M_Y<"``B1X0,4J@``@%([^?^7P```-```@%+S4T&I_7O"J,`#7]8?(`/58`)`
MN>OX_Y<`$$*Y``P4$A\00''@``!48`)`N>7X_Y<`$$*Y``P4$A\H0'$!_O]4
M00"`4N`#%*H"^?^7'P``<>`7GQKS4T&I_7O"J,`#7]80"H+2_V,PR^+_@=+]
M>P"I_0,`D?,+`/FS``#0]5L"J;4C`9'W8P.I]@,`JF/B1_GW`P&J````T.$#
M%:ID`$#YI"<(^00`@-(`H!"1<?C_EQ\``'%M!0!4`@0`4;0/`/FA``#0H\IB
M."'41_DX`$"Y@P,`-.(#`"I4?$"3X06`4N(#%*K@`Q6J)OG_E\`"`+3@`Q@J
ML_C_E^,#%*KB`Q6JX0,6JB?Y_Y>T#T#Y<^)'^:$G2/E@`D#Y(```RJ`"`+7U
M6T*I$`J"TO=C0ZG]>T"I\PM`^?]C,(O``U_6'R`#U<+\_S6T#T#YX`,8*IWX
M_Y?B`Q>JX0,6JGKX_Y?L__\7H```T`#41_D8`$"Y]___%[0/`/FC^/^7_7N_
MJ:```-#]`P"1`-1'^0``0+F-^/^7H@``T`,``-#]>\&H`0``T$+01_EC8`^1
M(>`0D<GX_Q?]>[ZI_0,`D?,+`/FS``#0<]9'^6`"0+E^^/^7Z___EV`"0+E[
M^/^7\PM`^?U[PJ@$``#0A"`>D0(``+`!``#0!0"`4N,#!*I"H#F1(6`1D=#X
M_Q<?(`/5$`J$TO]C,,L`"(+2_7L`J?T#`)'S4P&IM```T/5;`JFV`P"+@.)'
M^;/C`)$!`$#YH2<0^0$`@-(P^/^7Y`,`*@4``-`#``#0I<`1D6/@$9$B`(+2
M(0"`4N`#$ZKW]_^7`@""TN$#%JK@`Q.J__?_EP`#^#?S`P"J``0`$0!\0),B
M^/^7]0,`JL```+1S?D"3X0,6JN(#$ZK8]_^7OVHS.)3B1_G@`Q6JHB=0^8$"
M0/E!``'*(0$`M?-30:D0"H32]5M"J?U[0*G_8S"+P`-?UA4`@-+S__\72/C_
MEQ\@`]7(__\7'R`#U1`.@M+_8S#+_7L`J?T#`)'U6P*IM@``T/-3`:GU`P&J
MPN)'^?,#`*JADP&1````T$,`0/FC-PCY`P"`T@`@$I'"_?^7]`,`JN$%@%+@
M`Q.JA/C_ER`"`+0```#0X0,3J@!@$I$G_O^7X`,3JM;B1_FB-TCYP0)`^4$`
M`<JA#0"U\U-!J1`.@M+U6T*I_7M`J?]C,(O``U_6MQL`^>`#$ZJY(P#Y%P``
MT+LK`/FE]_^7X:(2D?D#`"K@`Q6JG??_E_L#`*K@"@"TN!\`^;6C`9&Z)P#Y
M&```T!H``-`8PQ*16D,0D6`#0#D`!P`TM```M.$#&ZK@`Q2J)OC_ER`%`#3@
M`QNJC_?_EV'#((LA\%\X/[P`<>$``%0`!`!18<,@BW_+(#@A\%\X/[P`<6#_
M_U0A!P`1(```"Q_\/W',`P!4Y`,;JKL``-`"`(+2(0"`4N8#$ZKE`QBJ`P``
MT.`#%:ICX!*1>_?_EWO71_E@`T"YV/?_EP(`")'A`Q6J``"`4GSW_Y?@```U
M8`-`N='W_Y<`$$*Y``P4$A\@0'%@`@!4X:(2D0``@-)B]_^7^P,`JJ#Y_[6W
M8T.IN6M$J;LK0/FF__\7'R`#U;0``+3A`QJJX`,4JN_W_Y=`_O\T^P,:JB``
M@%+3__\7(0"`4N`#%:K<]_^78/W_->$#%:H```#0`&`2D;_]_Y?@`Q6JN??_
ME[LK0/FW8T.IN6M$J93__Q>W&T#YN2-`^;LK0/F+__\7MV,#J;EK!*F[*P#Y
MM??_EP$`0#GB`P"JP0``-``$`)$_O`!Q0A"`F@$`0#F!__\UX`,"JL`#7]:`
M"`"T_7N^J?T#`)'S4P&I\P,`JA0`0#D4`P`T+_?_EP`$`-%B`@"+?P("Z^(#
M`%1@:F`X'[P`<:```%08```40`!`.1^\`'&A`@!40@0`T7\"`NMA__]4G[X`
M<>```%3S4T&I````L/U[PJ@`P!*1AO?_%Q\@`]7S4T&I````L/U[PJ@`0!"1
M@/?_%Q\@`]5``$`Y'[P`<8`!`%1"!`#1?P("ZV/__U1_`@+K8/W_5$($`-%_
M`@+KX@``5$``0#D?O`!Q@0``5$($`-%_`@+K8___5$(`$\M`"`"1'P1`\0@"
M`%2D``#0A*`"D0,`@M)"!`"1X0,3JN`#!*HS]_^7\U-!J?U[PJC``U_6'R`#
MU0```+``0!"17/?_%Q\@`]4``(#2]___%_U[N*D!``"P(6`/D0```+#]`P"1
M\U,!J;,``+#U6P*I```3D6/B1_D6``"P]V,#J1<``+`F'$&I8@!`^:(_`/D"
M`(#2)!1"J:8?!:DA8$!Y&```L*'C`'D4``"PI!<&J92"%)&U,P&1&/W_EP``
M`+``0!.1%?W_EP```+``8!.1$OW_EP```+``H!.1#_W_E\#"$Y$-_?^7````
ML```%)$*_?^7X"(2D0C]_Y<`0Q21!OW_E^`#%*H$_?^7````L`#`%)$!_?^7
M````L`!@$I'^_/^7````L.$#%:H``!61MOS_EX```+3A`P"JX`,4JB#]_Y<`
M``"PX0,5J@!@%9&N_/^7H```M`(``+#A`P"J0,`5D1?]_Y<```"PX0,5J@``
M%I&E_/^70`(`M.$#`*K@(A*1#_W_EP$``+#`PA.1(>`6D0O]_Y=SXD?YH3]`
M^6`"0/D@``#*0`,`M?-30:GU6T*I]V-#J?U[R*C``U_6````L.$#%:H`0!:1
MC_S_EX`!`+4!``"PM$,!D4(!@-(AH!:1H(<!D<[V_Y?@_/\U@6X`D0!#%)'R
M_/^7X___%^$#`*H`0Q21[OS_E]___Q?P]O^7'R`#U?U[O:G]`P"1\U,!J;,`
M`+"T``#08>)'^8`20+DB`$#YHA<`^0(`@-(?!``Q(`$`5'/B1_FB%T#Y80)`
M^4$``<HA`@"U\U-!J?U[PZC``U_6H9,`D0```+``0!219?S_E^$#`*H``(!2
MH0``M"``0#D?P`!Q!!A`>N`'GQJ`$@"Y[/__%\WV_Y?]>[^I_0,`D6[V_Y?M
M]O^7@```M```0/G]>\&HP`-?U@``@-+]__\7_7N[J?T#`)'S"P#YLP``L/5;
M`JD5``"P]QL`^;<"%Y%BXD?Y]@,`JJ$3`9'@`Q>J0P!`^:,G`/D#`(#20?S_
MEV`!`+2T#P#Y]`,`J@$`0#G!```TX0,6JASW_Y<@`@"TM`]`^04``!2T#T#Y
MX0,6JJ`"%Y&A_/^7<^)'^:$G0/E@`D#Y(```RJ`#`+7U6T*I\PM`^?<;0/G]
M>\6HP`-?UN`#%JHE]O^7]0,`JN`#%*HB]O^7H`(`BP`(`)%7]O^7Y@,4JN0#
M%JH%``"P`P``L*6@$I%CX!*1`@"`DO4#`*HA`(!2&?;_E^$#%:K@`Q>J@OS_
ME[0/0/G@__\7M`\`^8+V_Y<?(`/5$#J0TO]C,,NJ``#02D$`D0L$D-+]>P&I
M_4,`D:T#"XM$E4"I]5L#J;8``+#W(P#Y^B\`^?<#`*KS$P#YM3,"D<SB1_D:
M``"P0`5#J8X!0/FNS0#Y#@"`TD(-0JF@!PVI1AU$J:07":E()46IH@\,J4L-
M0/GA`Q6J2C%`^4`C$I&F'PZIJ*<*J:M3`/FJ7P#YZOO_EX```+0!`$`Y\P,`
MJ@$3`#6T#P#YN.<#J;LK`/F(__^7]`,`J@`3`+3@`Q2JW/7_EP#X?],`!`"1
M$?;_EX0"0#GY`P"JA`$`-````+#S`QFJ&&`7D>`#$ZKC`QBJ`@"`DB$`@%+2
M]?^7<PH`D80>0#@D__\UH&-`^6`+`+2X`P.1,P"`T@8``!0?(`/5<P8`D0`/
M$XL`@%_X8`H`M.$#%:K!^_^7]`,`JB#__[0!`$`YX?[_-"#]_Y>@_O\TX`,4
MJB/V_Y?[`P"JX`@`M.`#&ZJS]?^7\P,`JN`#&:JP]?^7$P`3"W,2$!$8``"P
M<WY`D^`#$ZKB]?^7YP,9J@7#$I'D`QNJ!@``L`,``+#&@!>18Z`7D0(`@)+T
M`P"J(0"`4J/U_Y<!.(!2X`,4JHSV_Y<?!``QH0``5('V_Y<%`$"YOT0`<<$,
M`%2[``"P>]='^6`#0+GV]?^7`@`(D>$#%*H``(!2.O;_E_D#`"H`!@`TH```
ML.,"0/GD`Q2J`@``L`#,1_E"`!F1(0"`4A,`@-(``$#Y$O;_E[0/0/FXYT.I
MNRM`^=;B1_D!!)#2H0,!B^`#$ZHBS$#YP0)`^4$``<JA.0"U]5M#J1`ZD-+]
M>T&I\Q-`^?<C0/GZ+T#Y_V,PB\`#7]:X0P*1%`"`4A/;=/BS`0"T8`)`.6`!
M`#3@`Q.JE`8`$<S\_Y<@__\TX`,3JL_U_Y?[`P"JH/7_M1/;=/BS_O^U&P"`
MTJG__Q=@`T"YO_7_EP`00KD`#!02'Q!`<8'Y_U2\+P#Y8`-`N;CU_Y<<&$*Y
M:O7_EY\#`&O`!0!4O"]`^</__Q<?(`/5_O[_E^`#$ZJV]?^7\P,`JLK__Q<?
M(`/5N*,"D1,`@%(`VW/X@`$`M.$#%:IS!@`10OO_EV#__[0!`$`Y(?__-*CU
M_Y?T`P"JH.O_M0#;<_C`_O^UH`&`TF[U_Y<4``"P^0,`JF0*@%*40A>17/__
M%Z```+#C`D#YY`,4J@(``+``S$?Y0N`7D2$`@%(3`(#2``!`^;?U_Y>T#T#Y
MN.=#J;LK0/FE__\78`-`N87U_Y<`$$*Y`"``$A\`!W'!^?]4X`,3JE/U_Y?A
M`Q6J\P,`J@```+``X!B1&/O_ER`+`+3U`D#Y?_7_E^$#`*K@`Q6J0/W_E_4#
M`*I`"@"TX`,5J@SU_Y?[`P"J'PP`<>T!`%0`?$"3`0``L``0`-$A8!J1H`(`
MBY?U_Y<``0`U?Q,`<<`C`%1@$P!1H,(@BP#P7S@?O`!Q(",`5(#^_Y?````U
M`0"`4N`#%:K.]?^7H'<`N4`'`#4!``"P(>`6D0```+``0!217_O_EQC#$I$A
M]?^7%0``L+4B'I'F`P`J`P``L.<#%:KE`QBJY`,4JF/@&I$"`("2(0"`4N`#
M$ZH7``"PY/3_E_<B&Y$2```4'R`#U<3U_Y<``$"Y'T0`<4$"`%0,]?^7]0,`
M^3D'`!'F`P`JYP,9*N4#&*KD`Q2JXP,7J@(`@)(A`(!2X`,3JM'T_Y<!.(!2
MX`,3JKKU_Y<?!``Q@/W_5.`#%*IV]?^7X0,3JD`C$I$S^_^7X`,3JG/^_Y>T
M#T#YN.=#J;MS1:D___\7]0)`^:[__Q>CXP:10@"`4O4#`ZHA`H"2HS\`^1'U
M_Y>@=T"YP@"`TN$#%:J!]?^7H.-&.8```#6@YT8Y'PP!<>`<`%2@=T"Y`@"`
M4@$`@-*YPP.1O*,$D0+U_Y>__Q&I(.,`D21@A-(C<972PI^;TL&.BM*@-P#Y
M`#Z<TJ3HK/*C^;WR0A>S\D$&HO)`>KCRI`\/J:('$*F_:P&YH(L`^:!W0+D"
M`)#2H3]`^6'U_Y?C`P"J]0,`*A\``'&M"`!4I8M1J6%\0).@:T&YI`P!"[\`
M!.M"E(*:071!BZ2'$:D`%``T`0B`4C4``$NA/T#Y?P`5:Z(W0/EUT)4:NWY`
MDZ,S`/E`P""+X@,;JFWT_Y>@:T&YHS-`^:`"``N@:P&Y'P`!<>'[_U2@/T#Y
M=0`52QL`&XO@`QFJ./;_E[_^`''-`@!4M0(!4:!^!E.@8P"Y%V0:4_<"`9%W
M`Q>+8`="J8`'`JED%T"IA!<`J6(/0:F"#P&I9A]#J88?`ZE[`P&1X`,9JB7V
M_Y?_`AOK@?[_5*!C0+FU&@!+H#=`^0,)@-*B?D"3X0,;JH+T_Y>U:P&YH'=`
MN0(`D-*A/T#Y'?7_E^,#`*KU`P`J'P``<:SW_U2@=T"YO_3_E[7?4:GB#X`2
MH2(#4R`$`!$?X`!Q@LLA.(P-`%0CXP"1`@>`4D(``$L!`(!20GQ`DV#`((N)
M]/^7X?Y8T^#^4-.A@P4YH?Y8TZ"'!3G@_DC3H(L%.:#^4-.@EP4YH/Y(T[>/
M!3F\(P:1H9,%.9NC`)&UGP4Y]0,<JJ";!3G@`QFJ\/7_E[G'!9&F%T^I````
ML*,+4*D78!>1H8M`^<C\4-/'_$C3H/Q8TZG\4-.HQP4YI\L%.:C\2--G_%C3
MH-,%.6#\2-/$?!A3IL\%.6K\4-.IUP4Y)OQ8TZC;!3E)_%C32/Q0TZ7?!3FG
MXP4Y)?Q0TT?\2-.@ZP4YI,,%.2#\2-.JYP4YH^\%.:GS!3FH]P4YI_L%.:+_
M!3FF`P8YI0<&.:`+!CFA#P8Y`P``%!\@`]4D%T`XX`,5JN,#%ZH"`("2(0"`
M4K4*`)'X\_^7?P,5ZP'__U0'``"PY@,<JN<@'I$#``"PO\,&.07#$I'D`Q2J
M8Z`:D0(`@)(A`(!2X`,3JNKS_Y<>__\7NS]`^7;__Q?W!D#Y]]S_M.`#%ZK?
M\_^7'PP`\6G<_U0`$`#1`0``L.`"`(LA@!J1;/3_EQ\``'&U$I>:V_[_%P((
M@%)"``!+0GQ`DP$`@%([XP"18,,@BQ[T_Y?@`QFJEO7_EZ"#")$?_#"I/_\$
MJ3__!:D_-P#YCO__%Z#K1CD?!`%Q`>/_5*#O1CD?#`%QH>+_5*#S1CD?(`%Q
M0>+_5*#W1CD?%`%QX>'_5+=W0+E"`(!2(0>`DN`#%RH1]/^7M3]`^2(%@-+@
M`Q<JX0,5JH#T_Y<'``"PY@,5J@,``+#G(!Z1O___%[CG`ZF[<P6IM`\`^1OT
M_Y?]>[BIH```L/T#`)'W&P#YMP``L/-3`:GSUD?Y]5L"J;73`9'Z)P#Y`.!'
M^;4S`/D!`$#YH3\`^0$`@-)@`D"Y^O/_E_0#`*I@`D"Y]_/_EX'B0CD!Y`(Y
M````L.$#%:H`P!.1C_G_EX```+0!`$`Y/\0`<2`4`%2<_/^7]M9'^<`"0+GI
M\_^7`0``L&,!@%(B`(!2(8`;D?SS_Y<@%@"TN!\`^:$``-`U(`*1H3<`^0$(
M0/G:`D"YH`9`N3@40/D?!`!Q[1D`5+DC`/D9@(!2NW,%J10`@%(S`(!2&02@
M<@L``!0?(`/580A`^>`#'*K^\_^7H09`N2`$`#5S!@`1E`8`$3\`$VNM`P!4
MX`,:*L;S_Y<#`(!2@GY`D^$#&*HJ]/^7^P,`JH`3`+0#`$#YI`9`^=H"0+E@
M#$"YG-AS^```&0H?`!!Q`/W_5.`#&BJV\_^780-`^4,`@%("`(#2HO/_E^$#
M`*K@`QRJW_/_E]H"0+FA!D"Y(/S_-"`$`%$?`!1K(`P`5+CG0ZF[<T6IX`,:
M*J7S_Y=C`(!2`0``D"(`@%(AH!N1N//_E_,#`*J@`0"T]-9'^8`"0+F;\_^7
M80I`^0(``)!"P!N1(0!`^7;S_Y=@"D#Y``!`^0`,0+E`$+`W]-9'^8`"0+F/
M\_^7`0``D&,`@%(B`(!2(>`;D:+S_Y?S`P"JH`$`M*$S0/D```"0`&`2D2+Y
M_Y?U`P"J@`)`N?4,`+2`\_^780I`^>(#%:HA`$#Y7//_E_?61_F@-T#Y%"`"
MD>`"0+EW\_^7\P,`JN`"0+ET\_^7(@"`4@$``)`A`!R1K//_EP(``)#A`P"J
M0F`<D>`#$ZI+\_^7X`)`N6GS_Y<?Y`(YH3-`^0```)``(!*1`OG_EX`*`/GS
M`P"J8`8`M`$X@%+@`Q.JZO/_EP$$`!$_!`!Q!(A1>J$*`%2@``"0&N!'^:$_
M0/E``T#Y(```RH`)`+7S4T&I]5M"J?<;0/GZ)T#Y_7O(J,`#7]8?(`/5``1`
M.0#L_S1>__\7'R`#U3\$`''M\_]4H#=`^3,`@%+UUD?Y%"`"D0,``!0?(`/5
MN@)`N>`#&BH^\_^7X0,8JOCR_Y>`!D"Y<P8`$1\`$VL,__]4X-9'^;CG0ZF[
M<T6I&@!`N8W__Q>@``"PV@)`N:`W`/F)__\7@`9`^;W\_Y>`"@#Y\P,`JD#Y
M_[4```"0N.<#J;MS!:D`@!R19?/_EZ$W0/G@UD?Y(2`"D2$$0+D:`$"Y(`0`
M41\`%&NA[O]4U/__%Q\@`]4:\_^7H#=`^6(*0/D`(`*1`01`^4``0/DA`$#Y
M._K_EY?__Q<?(`/5@`)`N0_S_Y=A"D#Y(0!`^63S_Y=Z__\7N!]`^6/__Q>X
MYP.INW,%J1;S_Y>A-T#YXP,`*KMS!:GB`Q.J/"`"D;CG`ZD!``"0("`=D8$'
M0/DA`$#Y._/_E_U[OJG]`P"1\U,!J?0#`*I<^_^7`0!`.?,#`*K!```T``0`
MD3^\`'%S$H":`0!`.8'__S4/_/^7GP(`\0080'J!``!4\U-!J?U[PJC``U_6
M@`)`.8#__S0!``"0@@"`TB&`%Y'@`Q.JQ/+_E\#^_S7@`Q2J\U-!J?U[PJAW
M^?\7HP``L&,$0/F8\O\7`````/U[O*G]`P"1]-<!J;0``)"U``"0E"(LD;4"
M+)'VWP*IE`(5R_@?`/F4_D.3]@,`*O<#`:KX`P*J2/+_EY0!`+2S"P#Y$P"`
MTJ-Z<_CB`QBJX0,7JN`#%BIS!@"18``_UI\"$^LA__]4LPM`^?370:GVWT*I
M^!]`^?U[Q*C``U_6P`-?UOU[OZG]`P"1_7O!J,`#7]8``````0`"``````!P
M97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("```````````"X`````````+BX````````E<R\E<P```"]P<F]C+W-E;&8O
M97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````%!!4E]4
M14U0``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S
M)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?
M0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!0
M05)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``````
M``!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X``````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!
M4EE?4$%42`!365-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@```````%!!5$@`````)7,Z('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@
M<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````'!A<FP`````+G!A<@`````E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,``````````$%21U8`````&`````````!P97)L`````#``````````4$%2
M.CI086-K97(Z.E9%4E-)3TX`````,2XP-#,```!5;F%B;&4@=&\@8W)E871E
M(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M````````)7,````````M90```````"TM````````55-%4@````!54T523D%-
M10``````````5$U01$E2``!414U01$E2`%1%35``````5$U0```````O=&UP
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H
M(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN
M="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H
M+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]
M"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I
M.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M
M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E
M("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````@)````````-@C
M`````````0`````````!``````````$`````````RP$````````!````````
M`-8!`````````0````````#@`0````````$`````````+P(````````!````
M`````(@#`````````0````````"P`P````````P`````````D!P````````-
M`````````+Q3````````&0``````````FP$``````!L`````````"```````
M```:``````````B;`0``````'``````````(`````````/7^_V\`````8`(`
M```````%`````````(@-````````!@````````!0`P````````H`````````
M%04````````+`````````!@`````````%0````````````````````,`````
M````8)T!```````"```````````&````````%``````````'`````````!<`
M````````D!8````````'`````````-@3````````"`````````"X`@``````
M``D`````````&``````````>``````````@`````````^___;P`````!```(
M`````/[__V\`````>!,```````#___]O``````,`````````\/__;P````">
M$@```````/G__V\`````$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+`<````````
ML!P```````"P'````````+`<````````L!P```````"P'````````+`<````
M````L!P```````"P'````````+`<````````L!P```````"P'````````+`<
M````````L!P```````"P'````````+`<````````L!P```````"P'```````
M`+`<````````L!P```````"P'````````+`<````````L!P```````"P'```
M`````+`<````````L!P```````"P'````````+`<````````L!P```````"P
M'````````+`<````````L!P```````"P'````````+`<````````L!P`````
M``"P'````````+`<````````L!P```````"P'````````+`<````````L!P`
M``````"P'````````+`<````````L!P```````"P'````````+`<````````
ML!P```````"P'````````+`<````````L!P```````"P'````````+`<````
M````L!P```````"P'````````+`<````````L!P```````"P'````````+`<
M````````L!P```````"P'````````+`<````````L!P```````"P'```````
M`+`<````````$)L!``````"X4P``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#A3``````````````````#0(```````````````````````````
M````````````````````````"*`!``````#_____`````.!7````````$%0`
M`````````````````'!5````````P%<```````#(5P```````-!7````````
MV%<``````````````````*A7````````L%<``````````````````.A7````
M````1T-#.B`H1&5B:6%N(#<N,RXP+3$V*2`W+C,N,`!'0T,Z("A$96)I86X@
M-RXS+C`M,3,I(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````(``````````@```````!L````````````````````!````````````
M````````$P````<````"`````````!P"````````'`(````````@````````
M````````````!````````````````````"$````'`````@`````````\`@``
M`````#P"````````)`````````````````````0````````````````````T
M````]O__;P(`````````8`(```````!@`@```````.P`````````!0``````
M```(````````````````````/@````L````"`````````%`#````````4`,`
M```````X"@````````8````#````"``````````8`````````$8````#````
M`@````````"(#0```````(@-````````%04```````````````````$`````
M``````````````!.````____;P(`````````GA(```````">$@```````-H`
M````````!0`````````"``````````(`````````6P```/[__V\"````````
M`'@3````````>!,```````!@``````````8````#````"```````````````
M`````&H````$`````@````````#8$P```````-@3````````N`(````````%
M``````````@`````````&`````````!T````!````$(`````````D!8`````
M``"0%@`````````&````````!0```!0````(`````````!@`````````?@``
M``$````&`````````)`<````````D!P````````4````````````````````
M!````````````````````'D````!````!@````````"P'````````+`<````
M````(`0``````````````````!``````````$`````````"$`````0````8`
M````````T"````````#0(````````.PR```````````````````(````````
M````````````B@````$````&`````````+Q3````````O%,````````0````
M````````````````!````````````````````)`````!`````@````````#0
M4P```````-!3````````4$````````````````````@`````````````````
M``"8`````0````(`````````()0````````@E`````````0`````````````
M```````$````````````````````H@````X````#``````````";`0``````
M`)L````````(````````````````````"``````````(`````````*X````/
M`````P`````````(FP$```````B;````````"`````````````````````@`
M````````"`````````"Z````!@````,`````````$)L!```````0FP``````
M`%`"````````!@`````````(`````````!``````````PP````$````#````
M`````&"=`0``````8)T```````"@`@``````````````````"``````````(
M`````````,@````!`````P``````````H`$```````"@````````@```````
M``````````````@```````````````````#.````"`````,`````````@*`!
M``````"`H````````"@0```````````````````(````````````````````
MTP````$````P````````````````````@*`````````Z````````````````
M`````0`````````!``````````$````#`````````````````````````+J@
F````````W`````````````````````$`````````````````````
